@@ -24,7 +24,7 @@ mod stats;
 mod class;
 mod creature;
 mod body;
-mod legendary;
+//mod legendary;
 mod tests;
 mod types;
 mod npc;
@@ -33,17 +33,69 @@ mod equation;
 mod special;
 mod attributes;
 mod effect;
+mod item;
 
-//use crate::stats::Basic as Stats;
+//use crate::stats::Advanced as ReadmeBuilder;
 //use crate::creature::Person;
 //use crate::legendary::Legendary;
 //use crate::stats::Builder;
 //use crate::attributes::Rate;
 extern crate clap;
 use clap::{App, load_yaml};
+//use toml::*;
+//use serde::{Deserialize, Serialize};
+
+
+// fltkform features
+#[cfg(feature = "fltkform")]
+use fltk::{prelude::*, *};
+#[cfg(feature = "fltkform")]
+use fltk_form::{FltkForm, HasProps};
+
+
+
+#[cfg(feature = "fltkform")]
+fn fltk_main() {
+    use crate::creature::Stats as Stats;
+
+    let app = app::App::default().with_scheme(app::Scheme::Gtk);
+    app::set_background_color(222, 222, 222);
+
+    let mut win = window::Window::default().with_size(400, 300);
+    let my_struct = Stats::default();
+    let grp = group::Scroll::default()
+        .with_size(300, 200)
+        .center_of_parent();
+    // inside group
+    let form = my_struct.view();
+    grp.end();
+    let mut btn = button::Button::default()
+        .with_label("print")
+        .with_size(80, 30)
+        .below_of(&grp, 5)
+        .center_x(&grp);
+    //grp.set_frame(enums::FrameType::EngravedFrame);
+    win.end();
+    win.show();
+
+    //let v = form.get_prop("hp"); // <-- get a single property
+    //assert_eq!(v, Some("3.0".to_owned()));
+
+    btn.set_callback(move |_| {
+        println!("{:?}", form.get_props()); // <-- get a HashMap of the properties
+    });
+
+    while app.wait() {
+       win.redraw();
+    }
+}
 
 fn main() {
-    //TODO make unused warnings go away by putting things here
+    #[cfg(feature = "fltkform")]
+    {
+        fltk_main();
+        return;
+    }
     let yaml = load_yaml!("cli.yaml");
     let matches = App::from(yaml).get_matches();
 
@@ -80,3 +132,4 @@ fn main() {
         //use crate::type::
     }
 }
+
